@@ -1,15 +1,16 @@
+# -*- coding: utf-8 -*-
+from collective.mailchimp.browser.newsletter import NewsletterSubcriber
 from collective.mailchimp.browser.newsletter import NewsletterSubscriberForm
-from zope.publisher.interfaces.browser import IDefaultBrowserLayer
-from zope import schema
-from zope.interface import implements
-from zope.interface import Interface
+from persistent import Persistent
 from plone.z3cform.fieldsets import extensible
-from zope.component import adapts, provideAdapter
+from zope import schema
 from zope.annotation import factory
 from zope.annotation.attribute import AttributeAnnotations
-from persistent import Persistent
-
-from collective.mailchimp.browser.newsletter import NewsletterSubcriber
+from zope.component import adapter
+from zope.component import provideAdapter
+from zope.interface import implementer
+from zope.interface import Interface
+from zope.publisher.interfaces.browser import IDefaultBrowserLayer
 
 
 class IExtraBehavior(Interface):
@@ -17,9 +18,9 @@ class IExtraBehavior(Interface):
     bar = schema.TextLine(title=u"Bar")
 
 
+@implementer(IExtraBehavior)
+@adapter(NewsletterSubcriber)
 class ExtraBehavior(Persistent):
-    implements(IExtraBehavior)
-    adapts(NewsletterSubcriber)
 
     foo = u""
     bar = u""
@@ -30,8 +31,8 @@ provideAdapter(ExtraBehavior)
 provideAdapter(AttributeAnnotations)
 
 
+@adapter(Interface, IDefaultBrowserLayer, NewsletterSubscriberForm)
 class ExtraBehaviorExtender(extensible.FormExtender):
-    adapts(Interface, IDefaultBrowserLayer, NewsletterSubscriberForm)
 
     def __init__(self, context, request, form):
         self.context = context
@@ -42,4 +43,5 @@ class ExtraBehaviorExtender(extensible.FormExtender):
         if 'extra.foo' not in self.form.fields.keys():
             self.add(IExtraBehavior, prefix="extra")
 
+
 provideAdapter(factory=ExtraBehaviorExtender, name=u"test.extender")  # noqa
